.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :end-before: This library also contains tools for rendering

.. toctree::
   :maxdepth: 2
   :hidden:

   basic_usage
   api_reference
   pymol_commands
